#!/bin/bash
#
# Copyright (c) 2021, Oracle and/or its affiliates.
#

set -o nounset -o errexit -o pipefail
set -m

SPRITE_X11_DIR_DEFAULT=/opt/oracle/sprite-x11
SPRITE_X11_DIR=${SPRITE_X11_HOME:-${SPRITE_X11_DIR_DEFAULT}}
SPRITE_X11_BIN="${SPRITE_X11_DIR}/bin"

# Pull in logging levels
source "${SPRITE_X11_BIN}/logging.sh"

PORT=9873
RATE=22050

display_usage()
{
    echo "Usage:"
    echo "  startAudioServer.sh [OPTION…]"
    echo ""
    echo "Options:"
    echo "  -h  This help message."
    echo "  -p  Port to listen on."
    echo "  -s  Sample rate to use."
}

while getopts ":hp:s:" opt; do
    case "${opt}" in
        h)
            display_usage
            exit 0
            ;;
        p)
            PORT=${OPTARG}
            ;;
        s)
            RATE=${OPTARG}
            ;;
        *)
            display_usage
            exit 1
            ;;
    esac
done

${SPRITE_X11_BIN}/audioserver -L "${SPRITE_X11_AUDIOSERVER_LOG_LEVEL}" -p $PORT -s $RATE &> /dev/null &
echo $!
